==> mhu-lib-core-3.2.9-sources.jar: de/mhus/lib/core/config/JsonConfigFile.java <==
package de.mhus.lib.core.config;

import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.InputStreamReader;

import de.mhus.lib.core.MFile;
import de.mhus.lib.errors.MException;

/**
 * <p>JsonConfigFile class.</p>
 *
 * @author mikehummel
 * @version $Id: $Id
 */
public class JsonConfigFile extends JsonConfig {

	private File file;

	/**
	 * <p>Constructor for JsonConfigFile.</p>
	 *
	 * @param file a {@link java.io.File} object.
	 * @throws java.lang.Exception if any.
	 */
	public JsonConfigFile(File file) throws Exception {
		super(MFile.readFile(file));
		this.file = file;
	}
	
	/**
	 * <p>Constructor for JsonConfigFile.</p>
	 *
	 * @param is a {@link java.io.InputStream} object.
	 * @throws java.lang.Exception if any.
	 */
	public JsonConfigFile(InputStream is) throws Exception {
		super(MFile.readFile(new InputStreamReader(is))); // read utf
		this.file = null;
	}
	
	/**
	 * <p>canSave.</p>
	 *
	 * @return a boolean.
	 */
	public boolean canSave() {
		return file != null && file.canWrite();
	}

	/**
	 * <p>save.</p>
	 *
	 * @throws de.mhus.lib.errors.MException if any.
	 */
	public void save() throws MException {
		try {
			if (!canSave()) return;
			log().t("save config",this);
			FileOutputStream os = new FileOutputStream(file);
			write(os);
			os.close();
		} catch (Exception e) {
			throw new MException(e);
		}
	}
	
	/** {@inheritDoc} */
	@Override
	public String toString() {
		return getClass() + ": " + (file == null ? "?" : file.getAbsolutePath());
	}

	/**
	 * <p>setName.</p>
	 *
	 * @param name a {@link java.lang.String} object.
	 */
	public void setName(String name) {
		this.name = name;
	}
	
	/**
	 * <p>Getter for the field <code>file</code>.</p>
	 *
	 * @return a {@link java.io.File} object.
	 */
	public File getFile() {
		return file;
	}

}

==> mhu-lib-core-3.3.5-sources.jar: de/mhus/lib/core/config/JsonConfigFile.java <==
/**
 * Copyright 2018 Mike Hummel
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.mhus.lib.core.config;

import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.InputStreamReader;

import de.mhus.lib.core.MFile;
import de.mhus.lib.errors.MException;

public class JsonConfigFile extends JsonConfig {

	private static final long serialVersionUID = 1L;
	private File file;

	public JsonConfigFile(File file) throws Exception {
		super(MFile.readFile(file));
		this.file = file;
	}
	
	public JsonConfigFile(InputStream is) throws Exception {
		super(MFile.readFile(new InputStreamReader(is))); // read utf
		this.file = null;
	}
	
	public boolean canSave() {
		return file != null && file.canWrite();
	}

	public void save() throws MException {
		try {
			if (!canSave()) return;
			log().t("save config",this);
			FileOutputStream os = new FileOutputStream(file);
			write(os);
			os.close();
		} catch (Exception e) {
			throw new MException(e);
		}
	}
	
	@Override
	public String toString() {
		return getClass() + ": " + (file == null ? "?" : file.getAbsolutePath());
	}

	public void setName(String name) {
		this.name = name;
	}
	
	public File getFile() {
		return file;
	}

}
